#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ItemDescriptor :
    def __init__( self):
        self.uid = None
        self.version = None
        self.displayName = None
        self.externalId = None
        self.internalId = None
        self.createdBy = None
        self.updatedBy = None
        self.created = None
        self.updated = None
        pass

class __ItemDescriptorSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ItemDescriptor()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        uidValue = value['uid']
        instance.uid = serder.STRING.parse(uidValue)
        versionValue = value['version']
        instance.version = serder.LONG.parse(versionValue)
        displayNameValue = value['displayName']
        instance.displayName = serder.STRING.parse(displayNameValue)
        externalIdValue = value['externalId']
        instance.externalId = serder.STRING.parse(externalIdValue)
        internalIdValue = value['internalId']
        instance.internalId = serder.LONG.parse(internalIdValue)
        createdByValue = value['createdBy']
        instance.createdBy = serder.STRING.parse(createdByValue)
        updatedByValue = value['updatedBy']
        instance.updatedBy = serder.STRING.parse(updatedByValue)
        createdValue = value['created']
        instance.created = serder.DATE.parse(createdValue)
        updatedValue = value['updated']
        instance.updated = serder.DATE.parse(updatedValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        uidValue = value.uid
        instance["uid"] = serder.STRING.encode(uidValue)
        versionValue = value.version
        instance["version"] = serder.LONG.encode(versionValue)
        displayNameValue = value.displayName
        instance["displayName"] = serder.STRING.encode(displayNameValue)
        externalIdValue = value.externalId
        instance["externalId"] = serder.STRING.encode(externalIdValue)
        internalIdValue = value.internalId
        instance["internalId"] = serder.LONG.encode(internalIdValue)
        createdByValue = value.createdBy
        instance["createdBy"] = serder.STRING.encode(createdByValue)
        updatedByValue = value.updatedBy
        instance["updatedBy"] = serder.STRING.encode(updatedByValue)
        createdValue = value.created
        instance["created"] = serder.DATE.encode(createdValue)
        updatedValue = value.updated
        instance["updated"] = serder.DATE.encode(updatedValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class AddressBookDescriptor :
    def __init__( self):
        self.name = None
        self.domainUid = None
        self.owner = None
        self.system = None
        self.settings = None
        self.orgUnitUid = None
        pass

class __AddressBookDescriptorSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = AddressBookDescriptor()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        domainUidValue = value['domainUid']
        instance.domainUid = serder.STRING.parse(domainUidValue)
        ownerValue = value['owner']
        instance.owner = serder.STRING.parse(ownerValue)
        systemValue = value['system']
        instance.system = serder.BOOLEAN.parse(systemValue)
        settingsValue = value['settings']
        instance.settings = serder.MapSerDer(serder.STRING).parse(settingsValue)
        orgUnitUidValue = value['orgUnitUid']
        instance.orgUnitUid = serder.STRING.parse(orgUnitUidValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        domainUidValue = value.domainUid
        instance["domainUid"] = serder.STRING.encode(domainUidValue)
        ownerValue = value.owner
        instance["owner"] = serder.STRING.encode(ownerValue)
        systemValue = value.system
        instance["system"] = serder.BOOLEAN.encode(systemValue)
        settingsValue = value.settings
        instance["settings"] = serder.MapSerDer(serder.STRING).encode(settingsValue)
        orgUnitUidValue = value.orgUnitUid
        instance["orgUnitUid"] = serder.STRING.encode(orgUnitUidValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Status :
    def __init__( self):
        self.type = None
        self.message = None
        self.phoneState = None
        pass

class __StatusSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = Status()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.cti.api.StatusType import StatusType
        from netbluemind.cti.api.StatusType import __StatusTypeSerDer__
        typeValue = value['type']
        instance.type = __StatusTypeSerDer__().parse(typeValue)
        messageValue = value['message']
        instance.message = serder.STRING.parse(messageValue)
        from netbluemind.cti.api.StatusPhoneState import StatusPhoneState
        from netbluemind.cti.api.StatusPhoneState import __StatusPhoneStateSerDer__
        phoneStateValue = value['phoneState']
        instance.phoneState = __StatusPhoneStateSerDer__().parse(phoneStateValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.cti.api.StatusType import StatusType
        from netbluemind.cti.api.StatusType import __StatusTypeSerDer__
        typeValue = value.type
        instance["type"] = __StatusTypeSerDer__().encode(typeValue)
        messageValue = value.message
        instance["message"] = serder.STRING.encode(messageValue)
        from netbluemind.cti.api.StatusPhoneState import StatusPhoneState
        from netbluemind.cti.api.StatusPhoneState import __StatusPhoneStateSerDer__
        phoneStateValue = value.phoneState
        instance["phoneState"] = __StatusPhoneStateSerDer__().encode(phoneStateValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailboxFolderHierarchy_VERSION = "3.1.42822"

class IMailboxFolderHierarchy(BaseEndpoint):
    def __init__(self, apiKey, url ,mailboxUid ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/mailbox-folders/{mailboxUid}'
        self.mailboxUid_ = mailboxUid
        self.base = self.base.replace('{mailboxUid}',mailboxUid)

    def multipleGet (self, arg0 ):
        postUri = "/_mget";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(arg0)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__FolderSerDer__())), response)
    def byUid (self, uid ):
        postUri = "/by_uid";
        __data__ = None
        __encoded__ = None
        queryParams = {  'uid': uid   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
    def allUids (self):
        postUri = "/_alluids";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
    def byParentId (self, parent ):
        postUri = "/by_parent_id";
        __data__ = None
        __encoded__ = None
        queryParams = {  'parent': parent   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__FolderSerDer__())), response)
    def changelog (self, arg0 ):
        postUri = "/_changelog";
        __data__ = None
        __encoded__ = None
        __data__ = serder.LONG.encode(arg0)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
        from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
        return self.handleResult__(__ContainerChangelogSerDer__(), response)
    def changeset (self, since ):
        postUri = "/_changeset";
        __data__ = None
        __encoded__ = None
        queryParams = {  'since': since   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
    def changesetById (self, since ):
        postUri = "/_changesetById";
        __data__ = None
        __encoded__ = None
        queryParams = {  'since': since   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.LONG), response)
    def getComplete (self, uid ):
        postUri = "/{uid}/complete";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
    def search (self, arg0 ):
        postUri = "/_search";
        __data__ = None
        __encoded__ = None
        from netbluemind.folder.api.FolderQuery import FolderQuery
        from netbluemind.folder.api.FolderQuery import __FolderQuerySerDer__
        __data__ = __FolderQuerySerDer__().encode(arg0)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__FolderSerDer__())), response)
    def byPath (self, path ):
        postUri = "/_byPath";
        __data__ = None
        __encoded__ = None
        queryParams = {  'path': path   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
    def createUserMailFolder (self, imapPath ):
        postUri = "/_createUserMailFolder";
        __data__ = None
        __encoded__ = None
        queryParams = {  'imapPath': imapPath   };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
    def reset (self):
        postUri = "/_reset";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def byContentUri (self, uri ):
        postUri = "/by_uri";
        __data__ = None
        __encoded__ = None
        queryParams = {  'uri': uri   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)
    def byId (self, id ):
        postUri = "/by_id";
        __data__ = None
        __encoded__ = None
        queryParams = {  'id': id   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IMailboxFolderHierarchy_VERSION}, data = __encoded__);
        from netbluemind.folder.api.Folder import Folder
        from netbluemind.folder.api.Folder import __FolderSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__FolderSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IDomains_VERSION = "3.1.42822"

class IDomains(BaseEndpoint):
    def __init__(self, apiKey, url ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/domains'

    def all (self):
        postUri = "";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DomainSerDer__())), response)
    def findByNameOrAliases (self, name ):
        postUri = "/_lookup";
        __data__ = None
        __encoded__ = None
        queryParams = {  'name': name   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__DomainSerDer__()), response)
    def setAliases (self, uid , aliases ):
        postUri = "/{uid}/_aliases";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        __data__ = serder.SetSerDer(serder.STRING).encode(aliases)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def deleteDomainItems (self, uid ):
        postUri = "/{uid}/_items";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)
    def update (self, uid , domain ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        __data__ = __DomainSerDer__().encode(domain)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def delete (self, uid ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def get (self, uid ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__DomainSerDer__()), response)
    def create (self, uid , domain ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.domain.api.Domain import Domain
        from netbluemind.domain.api.Domain import __DomainSerDer__
        __data__ = __DomainSerDer__().encode(domain)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def setRoles (self, uid , roles ):
        postUri = "/{uid}/roles";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        __data__ = serder.SetSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getRoles (self, uid ):
        postUri = "/{uid}/roles";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDomains_VERSION}, data = __encoded__);
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElement :
    def __init__( self):
        self.dtstart = None
        self.summary = None
        self.classification = None
        self.location = None
        self.description = None
        self.priority = None
        self.alarm = None
        self.status = None
        self.attendees = None
        self.organizer = None
        self.categories = None
        self.exdate = None
        self.rdate = None
        self.rrule = None
        self.url = None
        self.attachments = None
        self.sequence = None
        self.draft = None
        pass

class __ICalendarElementSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ICalendarElement()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dtstartValue = value['dtstart']
        instance.dtstart = __BmDateTimeSerDer__().parse(dtstartValue)
        summaryValue = value['summary']
        instance.summary = serder.STRING.parse(summaryValue)
        from netbluemind.icalendar.api.ICalendarElementClassification import ICalendarElementClassification
        from netbluemind.icalendar.api.ICalendarElementClassification import __ICalendarElementClassificationSerDer__
        classificationValue = value['classification']
        instance.classification = __ICalendarElementClassificationSerDer__().parse(classificationValue)
        locationValue = value['location']
        instance.location = serder.STRING.parse(locationValue)
        descriptionValue = value['description']
        instance.description = serder.STRING.parse(descriptionValue)
        priorityValue = value['priority']
        instance.priority = serder.INT.parse(priorityValue)
        from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
        from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
        alarmValue = value['alarm']
        instance.alarm = serder.ListSerDer(__ICalendarElementVAlarmSerDer__()).parse(alarmValue)
        from netbluemind.icalendar.api.ICalendarElementStatus import ICalendarElementStatus
        from netbluemind.icalendar.api.ICalendarElementStatus import __ICalendarElementStatusSerDer__
        statusValue = value['status']
        instance.status = __ICalendarElementStatusSerDer__().parse(statusValue)
        from netbluemind.icalendar.api.ICalendarElementAttendee import ICalendarElementAttendee
        from netbluemind.icalendar.api.ICalendarElementAttendee import __ICalendarElementAttendeeSerDer__
        attendeesValue = value['attendees']
        instance.attendees = serder.ListSerDer(__ICalendarElementAttendeeSerDer__()).parse(attendeesValue)
        from netbluemind.icalendar.api.ICalendarElementOrganizer import ICalendarElementOrganizer
        from netbluemind.icalendar.api.ICalendarElementOrganizer import __ICalendarElementOrganizerSerDer__
        organizerValue = value['organizer']
        instance.organizer = __ICalendarElementOrganizerSerDer__().parse(organizerValue)
        from netbluemind.tag.api.TagRef import TagRef
        from netbluemind.tag.api.TagRef import __TagRefSerDer__
        categoriesValue = value['categories']
        instance.categories = serder.ListSerDer(__TagRefSerDer__()).parse(categoriesValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        exdateValue = value['exdate']
        instance.exdate = serder.SetSerDer(__BmDateTimeSerDer__()).parse(exdateValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        rdateValue = value['rdate']
        instance.rdate = serder.SetSerDer(__BmDateTimeSerDer__()).parse(rdateValue)
        from netbluemind.icalendar.api.ICalendarElementRRule import ICalendarElementRRule
        from netbluemind.icalendar.api.ICalendarElementRRule import __ICalendarElementRRuleSerDer__
        rruleValue = value['rrule']
        instance.rrule = __ICalendarElementRRuleSerDer__().parse(rruleValue)
        urlValue = value['url']
        instance.url = serder.STRING.parse(urlValue)
        from netbluemind.attachment.api.AttachedFile import AttachedFile
        from netbluemind.attachment.api.AttachedFile import __AttachedFileSerDer__
        attachmentsValue = value['attachments']
        instance.attachments = serder.ListSerDer(__AttachedFileSerDer__()).parse(attachmentsValue)
        sequenceValue = value['sequence']
        instance.sequence = serder.INT.parse(sequenceValue)
        draftValue = value['draft']
        instance.draft = serder.BOOLEAN.parse(draftValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        dtstartValue = value.dtstart
        instance["dtstart"] = __BmDateTimeSerDer__().encode(dtstartValue)
        summaryValue = value.summary
        instance["summary"] = serder.STRING.encode(summaryValue)
        from netbluemind.icalendar.api.ICalendarElementClassification import ICalendarElementClassification
        from netbluemind.icalendar.api.ICalendarElementClassification import __ICalendarElementClassificationSerDer__
        classificationValue = value.classification
        instance["classification"] = __ICalendarElementClassificationSerDer__().encode(classificationValue)
        locationValue = value.location
        instance["location"] = serder.STRING.encode(locationValue)
        descriptionValue = value.description
        instance["description"] = serder.STRING.encode(descriptionValue)
        priorityValue = value.priority
        instance["priority"] = serder.INT.encode(priorityValue)
        from netbluemind.icalendar.api.ICalendarElementVAlarm import ICalendarElementVAlarm
        from netbluemind.icalendar.api.ICalendarElementVAlarm import __ICalendarElementVAlarmSerDer__
        alarmValue = value.alarm
        instance["alarm"] = serder.ListSerDer(__ICalendarElementVAlarmSerDer__()).encode(alarmValue)
        from netbluemind.icalendar.api.ICalendarElementStatus import ICalendarElementStatus
        from netbluemind.icalendar.api.ICalendarElementStatus import __ICalendarElementStatusSerDer__
        statusValue = value.status
        instance["status"] = __ICalendarElementStatusSerDer__().encode(statusValue)
        from netbluemind.icalendar.api.ICalendarElementAttendee import ICalendarElementAttendee
        from netbluemind.icalendar.api.ICalendarElementAttendee import __ICalendarElementAttendeeSerDer__
        attendeesValue = value.attendees
        instance["attendees"] = serder.ListSerDer(__ICalendarElementAttendeeSerDer__()).encode(attendeesValue)
        from netbluemind.icalendar.api.ICalendarElementOrganizer import ICalendarElementOrganizer
        from netbluemind.icalendar.api.ICalendarElementOrganizer import __ICalendarElementOrganizerSerDer__
        organizerValue = value.organizer
        instance["organizer"] = __ICalendarElementOrganizerSerDer__().encode(organizerValue)
        from netbluemind.tag.api.TagRef import TagRef
        from netbluemind.tag.api.TagRef import __TagRefSerDer__
        categoriesValue = value.categories
        instance["categories"] = serder.ListSerDer(__TagRefSerDer__()).encode(categoriesValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        exdateValue = value.exdate
        instance["exdate"] = serder.SetSerDer(__BmDateTimeSerDer__()).encode(exdateValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        rdateValue = value.rdate
        instance["rdate"] = serder.SetSerDer(__BmDateTimeSerDer__()).encode(rdateValue)
        from netbluemind.icalendar.api.ICalendarElementRRule import ICalendarElementRRule
        from netbluemind.icalendar.api.ICalendarElementRRule import __ICalendarElementRRuleSerDer__
        rruleValue = value.rrule
        instance["rrule"] = __ICalendarElementRRuleSerDer__().encode(rruleValue)
        urlValue = value.url
        instance["url"] = serder.STRING.encode(urlValue)
        from netbluemind.attachment.api.AttachedFile import AttachedFile
        from netbluemind.attachment.api.AttachedFile import __AttachedFileSerDer__
        attachmentsValue = value.attachments
        instance["attachments"] = serder.ListSerDer(__AttachedFileSerDer__()).encode(attachmentsValue)
        sequenceValue = value.sequence
        instance["sequence"] = serder.INT.encode(sequenceValue)
        draftValue = value.draft
        instance["draft"] = serder.BOOLEAN.encode(draftValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IComputerTelephonyIntegration_VERSION = "3.1.42822"

class IComputerTelephonyIntegration(BaseEndpoint):
    def __init__(self, apiKey, url ,domainUid ,userUid ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/cti/{domainUid}/{userUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}',domainUid)
        self.userUid_ = userUid
        self.base = self.base.replace('{userUid}',userUid)

    def forward (self, component , phoneNumber ):
        postUri = "/forward/{component}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{component}",component);
        queryParams = {   'phoneNumber': phoneNumber   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IComputerTelephonyIntegration_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getStatus (self):
        postUri = "/status";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IComputerTelephonyIntegration_VERSION}, data = __encoded__);
        from netbluemind.cti.api.Status import Status
        from netbluemind.cti.api.Status import __StatusSerDer__
        return self.handleResult__(__StatusSerDer__(), response)
    def setStatus (self, component , status ):
        postUri = "/status/{component}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{component}",component);
        from netbluemind.cti.api.Status import Status
        from netbluemind.cti.api.Status import __StatusSerDer__
        __data__ = __StatusSerDer__().encode(status)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IComputerTelephonyIntegration_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def dial (self, number ):
        postUri = "/dial";
        __data__ = None
        __encoded__ = None
        queryParams = {  'number': number   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IComputerTelephonyIntegration_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IJob_VERSION = "3.1.42822"

class IJob(BaseEndpoint):
    def __init__(self, apiKey, url ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/scheduledjobs'

    def deleteExecutions (self, executions ):
        postUri = "/_deleteExecutions";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.INT).encode(executions)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IJob_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getLogs (self, jobExecution , offset ):
        postUri = "/_logs";
        __data__ = None
        __encoded__ = None
        from netbluemind.scheduledjob.api.JobExecution import JobExecution
        from netbluemind.scheduledjob.api.JobExecution import __JobExecutionSerDer__
        __data__ = __JobExecutionSerDer__().encode(jobExecution)
        __encoded__ = json.dumps(__data__)
        queryParams = {   'offset': offset   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IJob_VERSION}, data = __encoded__);
        from netbluemind.scheduledjob.api.LogEntry import LogEntry
        from netbluemind.scheduledjob.api.LogEntry import __LogEntrySerDer__
        return self.handleResult__(serder.SetSerDer(__LogEntrySerDer__()), response)
    def start (self, jobId , domainName ):
        postUri = "/_start/{jobId}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{jobId}",jobId);
        queryParams = {   'domainName': domainName   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IJob_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def searchJob (self, query ):
        postUri = "/_searchJob";
        __data__ = None
        __encoded__ = None
        from netbluemind.scheduledjob.api.JobQuery import JobQuery
        from netbluemind.scheduledjob.api.JobQuery import __JobQuerySerDer__
        __data__ = __JobQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IJob_VERSION}, data = __encoded__);
        from netbluemind.scheduledjob.api.Job import Job
        from netbluemind.scheduledjob.api.Job import __JobSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__JobSerDer__()), response)
    def update (self, job ):
        postUri = "/_updateJob";
        __data__ = None
        __encoded__ = None
        from netbluemind.scheduledjob.api.Job import Job
        from netbluemind.scheduledjob.api.Job import __JobSerDer__
        __data__ = __JobSerDer__().encode(job)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IJob_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def searchExecution (self, query ):
        postUri = "/_searchExecution";
        __data__ = None
        __encoded__ = None
        from netbluemind.scheduledjob.api.JobExecutionQuery import JobExecutionQuery
        from netbluemind.scheduledjob.api.JobExecutionQuery import __JobExecutionQuerySerDer__
        __data__ = __JobExecutionQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IJob_VERSION}, data = __encoded__);
        from netbluemind.scheduledjob.api.JobExecution import JobExecution
        from netbluemind.scheduledjob.api.JobExecution import __JobExecutionSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__JobExecutionSerDer__()), response)
    def deleteExecution (self, jobExecutionId ):
        postUri = "/_deleteExecution";
        __data__ = None
        __encoded__ = None
        queryParams = {  'jobExecutionId': jobExecutionId   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IJob_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getJobFromId (self, jobId ):
        postUri = "/_job/{jobId}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{jobId}",jobId);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IJob_VERSION}, data = __encoded__);
        from netbluemind.scheduledjob.api.Job import Job
        from netbluemind.scheduledjob.api.Job import __JobSerDer__
        return self.handleResult__(__JobSerDer__(), response)
